# search, a bzr plugin for searching within bzr branches/repositories.
# Copyright (C) 2008 Robert Collins
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# 

"""search is a bzr plugin for searching bzr content.

Commands
========

`bzr search TERM` will return the list of documents TERM occurs in.

`bzr index [URL]` will create an index of a branch.

Documentation
=============

See `bzr help search` or `bzr help plugins/search`.
"""

import bzrlib.commands

# Relative because at __init__ time the module does not exist.
from bzrlib.branch import Branch
import commands
import errors


for command in [
    'index',
    'search',
    ]:
    bzrlib.commands.register_command(getattr(commands, 'cmd_' + command))


version_info = (1, 6, 0, 'dev', 0)


def auto_index_branch(result):
    """Handled for the post_change_branch_tip hook to update a search index."""
    try:
        search_index = index.open_index_branch(result.branch)
    except errors.NoSearchIndex:
        return
    search_index.index_branch(result.branch, result.new_revid)


def _install_hooks():
    """Install the hooks this plugin uses."""
    Branch.hooks.install_named_hook('post_change_branch_tip',
        auto_index_branch, "index")


_install_hooks()


def test_suite():
    # Thunk across to load_tests for niceness with older bzr versions
    from bzrlib.tests import TestLoader
    loader = TestLoader()
    return loader.loadTestsFromModuleNames(['bzrlib.plugins.search'])


def load_tests(standard_tests, module, loader):
    standard_tests.addTests(loader.loadTestsFromModuleNames(
        ['bzrlib.plugins.search.tests']))
    return standard_tests
